.. shodan-python documentation master file, created by
   sphinx-quickstart on Thu Jan 23 00:56:29 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

shodan - The official Python library for the Shodan search engine
=================================================================

This is the official Python wrapper around both the Shodan REST API as well as the experimental
Streaming API. And as a bonus it also lets you search for exploits using the Shodan Exploits REST API.
If you're not sure where to start simply go through the "Getting Started" section of the documentation and work your
way down through the examples.

For more information about Shodan and how to use the API please visit our official help center at:

    https://help.shodan.io

Introduction
~~~~~~~~~~~~
.. toctree::
    :maxdepth: 2

    tutorial

Examples
~~~~~~~~
.. toctree::
    :maxdepth: 2

    examples/basic-search
    examples/query-summary
    examples/cert-stream
    examples/gifcreator

API Reference
~~~~~~~~~~~~~
.. toctree::
    :maxdepth: 2

    api
